%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [build index contig_depth] = contig_build_simple(startvals,tumorid,link,dist)

utumorid    = unique(tumorid);

c_depth     = [];
contigs     = [];
singletons  = [];
s_index     = [];
c_index     = [];
for i = 1:length(utumorid)
    I                   = find(strcmp(utumorid(i),tumorid)); %Find insertions of one tumor
    %Cluster the insertions of one tumor:
    [c_tmp s_tmp CI cont_I sing_I]    = inshclust(startvals(I),link,dist);
    %Add the singletons
    singletons          = [singletons(:); s_tmp];
    s_index             = [s_index; I(sing_I(:))]; %Store the original index of the first insertion in the contig
    %Keep track of the tumorid of the singletons
    for ci = (unique(CI))'
        c_insertions    = c_tmp(find(CI==ci)); %Select insertions from a contig
        contigs         = [contigs(:); round(median(c_insertions))]; %Add
        c_depth         = [c_depth(:); length(c_insertions)]; %Determine the depth
        c_index         = [c_index; I(CI(1))]; %Store the original index of the first insertion in the contig
    end
end

[build, I]  = sort([singletons(:); contigs(:)]); %Sort insertion loci
depth       = [ones(length(singletons),1); c_depth]; %Stack depths of singletons and contigs
contig_depth= depth(I); %Sort them in the same way
index       = [s_index; c_index];
index       = index(I);
%%%%%%%%%%%%%%%%%%% SUB FUNCTIONS %%%%%%%%%%%%%%%%%%%%%%%
function [contigs singletons CI contigs_I singletons_I] = inshclust(data,link,dist)
% Contigs give the contig insertions
% Singletons give the singleton insertions
% CI is a label into the contigs vector
% contigs = data(contigs_I)
% singeltons = data(singletons_I)

%In case the tumor consists of only one insertion: set singleton and RETURN
if length(data)==1
    singletons      = data;
    contigs         = [];
    CI              = [];
    contigs_I       = [];
    singletons_I    = 1;
    return
end

%In case the tumor consists of two insertions: check contig and RETURN
if length(data)==2
    if abs(data(1)-data(2))<dist
        singletons  = [];
        contigs     = data;
        CI          = [1; 1];
        contigs_I   = [1; 2];
        singletons_I= [];
    else
        singletons      = data;
        contigs         = [];
        CI              = [];
        contigs_I       = [];
        singletons_I    = [1; 2];
    end
    return
end

distdata = pdist([data(:) zeros(length(data))]); %Interdata distance
dend = linkage(distdata,link); %Dendrogram with MATLAB build-in
C = cluster(dend,'cutoff',dist,'criterion','distance'); %Cut at distance
ins_cnt = histc(C,unique(C)); %Count insertion in unique clusters

I = [];
for i = (find(ins_cnt<2))' %Index the singletons
    I = [I(:); find(C==i)];
end
singletons      = data(I); %Store the singletons
singletons_I    = I;

c_clusters      = find(ins_cnt>1);
I               = [];
CI              = []; %Contig index, allows selection of insertions from 1 contig
cnt             = 1;
for i = c_clusters' %Index the contigs
    J   = find(C==i);
    I   = [I; J];
    CI  = [CI(:); cnt*ones(length(J),1)];
    cnt = cnt+1;
end
CI          = CI(:);
contigs     = data(I);
contigs_I   = I;



