%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function c = jchoosek(v)
%Adapted from MATLABs NCHOOSEK

m = size(v,1);

k = 2;
n = m; 
v = v.';

if n == k
    c = v(:).';
elseif n == k + 1
    tmp = v(:).';
    c   = tmp(ones(n,1),:);
    c(1:n+1:n*n) = [];
    c = reshape(c,n,n-1);
elseif n < 17 && (k > 3 || n-k < 4)
    rows = 2.^(n);
    ncycles = rows;

    for count = 1:n
        settings = [1 0];
        ncycles = ncycles/2;
        nreps = rows./(2*ncycles);
        settings = settings(ones(1,nreps),:);
        settings = settings(:);
        settings = settings(:,ones(1,ncycles));
        x(:,n-count+1) = settings(:);
    end

    idx = x(sum(x,2) == k,:);
    nrows = size(idx,1);
    [rows,ignore] = find(idx');
    c = reshape(v(rows),k,nrows).';
else
    c = [];
    if k < n && k > 1
        for idx = 1:n-k+1
            Q = combs(v(idx+1:n),k-1);
            c = [c; [v(ones(size(Q,1),1),idx) Q]];
        end
    end

end

%----------------------------------------
function P = combs(v,m)
%COMBS  All possible combinations.
%   COMBS(1:N,M) or COMBS(V,M) where V is a row vector of length N,
%   creates a matrix with N!/((N-M)! M!) rows and M columns containing
%   all possible combinations of N elements taken M at a time.
%
%   This function is only practical for situations where M is less
%   than about 15.

%v = v(:).'; % Make sure v is a row vector.
n = length(v);
if n == m
    P = v;
elseif m == 1
    P = v.';
else
    P = [];
    if m < n && m > 1
        for k = 1:n-m+1
            Q = combs(v(k+1:n),m-1);
            P = [P; [v(ones(size(Q,1),1),k) Q]];
        end
    end
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
