%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Function to compute the peaks in the cooccurrence space
function [fval] = local_parzen2D_contour(in,x,h,T)
h = [h,h];
NN=size(in,1);
XX = size(x,1);
%precompute constants that only depend on h
h1s = h(1)^2;
h2s = h(2)^2;
denom = (2*(h(1)*h(2))^2);

fval = zeros(XX,1);
for i = 1:XX
    fval(i) = parz2Doptim(x(i,:),in,NN,h1s,h2s,denom,1,T);
end

function f = parz2Doptim(x,in,K,h1s,h2s,denom,C,T)
f_arg = zeros(1,K);
for i = 1:K
    x1 = in(i,1);
    x2 = in(i,2);
    f_arg(i) = exp(-(h2s*((x(1)-x1)^2)+h1s*((x(2)-x2)^2))/denom);
end
f = C*sum(f_arg);
