%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = plot3d_scale(X,Y,Z,synonyms,C,chrom_l)
clf
h1 = [];
label_H = logspace(log(10000)/log(10),log(500000)/log(10),100);
if size(X{1},1)<2
    return
end

for i = 1:sum(~cellfun(@isempty,X))
    %Close the circles
    X{i} = [X{i} X{i}(:,1)];
    Y{i} = [Y{i} Y{i}(:,1)];
    Z{i} = [Z{i} Z{i}(:,1)];

    h1(i) = surf(X{i},Y{i},Z{i}); hold on
    plot3(X{i}(1:2:end,:)',Y{i}(1:2:end,:)',Z{i}(1:2:end,:)','k','linewidth',1.2)
    plot(X{i}(1:4:end,:)',Y{i}(1:4:end,:)','color',[0.2 0.2 0.2],'linewidth',0.2)


end
set(h1,'faceAlpha',0.4,'edgeAlpha',0.15)

axis tight
xl = get(gca,'xlim');
yl = get(gca,'ylim');
set(gca,'zlim',[0 100]);
max_lim = max((xl(2)-xl(1)),(yl(2)-yl(1)));
xl = [(xl(2)+xl(1)-max_lim)/2 (xl(2)+xl(1)+max_lim)/2];
set(gca,'xlim',xl);
yl = [(yl(2)+yl(1)-max_lim)/2 (yl(2)+yl(1)+max_lim)/2];
set(gca,'ylim',yl);
c = lines(6);
gchr = cell2mat(synonyms(:,2));
gstrt = cell2mat(synonyms(:,3));
gend = cell2mat(synonyms(:,4));
gstrnd = cell2mat(synonyms(:,5));
gname = cellstr(synonyms(:,6));
Iempty = strcmp(gname,'');
gname(Iempty) = cellstr(synonyms(Iempty,1));

ins = C(C(:,1)>xl(1) & C(:,1)<xl(2) & C(:,2)>yl(1) & C(:,2)<yl(2),:);
ins_h = plot3(ins(:,1),ins(:,2),zeros(size(ins,1),1)+0.4,'v','markersize',8,...
    'markerfacecolor','r','markeredgecolor','k');

chrom_l = [0; cumsum(chrom_l)];
[CHR, START] = abs2chrom(xl,chrom_l,0);

I = find(gchr==CHR(1) & gstrt>START(1) &gend < START(2));
[dummy,II] = sort(gstrt(I));
I = I(II);

top = find(gstrnd(I)==1);
bot = find(gstrnd(I)==-1);

if ~isempty(top)
    p1 = patch([gstrt(I(top)) gend(I(top)) gend(I(top)) gstrt(I(top))]'+chrom_l(CHR(1)),...
        repmat([yl(1) yl(1) yl(2) yl(2)]',1,length(I(top))),...
        repmat(0.1,4,length(I(top))),...
        [0 1 1],'facealpha',0.6,'edgecolor','k','edgealpha',0.4);
end
if ~isempty(bot)
    p1 = patch([gstrt(I(bot)) gend(I(bot)) gend(I(bot)) gstrt(I(bot))]'+chrom_l(CHR(1)),...
        repmat([yl(1) yl(1) yl(2) yl(2)]',1,length(I(bot))),...
        [0 0.5 1],'facealpha',0.7,'edgecolor','k','edgealpha',0.4);
end


ztext = 10*ones(length(I),1);
ztext(2:2:end) = ztext(2:2:end)+5;

line([(gstrt(I)+gend(I))/2+chrom_l(CHR(1)) (gstrt(I)+gend(I))/2+chrom_l(CHR(1))]',...
    [repmat(yl(2),length(I),1) repmat(yl(2),length(I),1)]',...
    [repmat(0,length(I),1) repmat(10,length(I),1)]','color','k')
t1 = text((gstrt(I)+gend(I))/2+chrom_l(CHR(1)),repmat(yl(2),length(I),1),ztext,gname(I),...
    'rotation',0,'interpreter','none','backgroundcolor',[1 1 0.6],'horizontalalignment','right');

gname(I)

[CHR, START] = abs2chrom(yl,chrom_l,0);

I = find(gchr==CHR(1) & gstrt>START(1) &gend < START(2));
[dummy,II] = sort(gstrt(I));
I = I(II);

top = find(gstrnd(I)==1);
bot = find(gstrnd(I)==-1);
if ~isempty(top)
    p2 = patch(repmat([xl(1) xl(1) xl(2) xl(2)]',1,length(I(top))),...
        [gstrt(I(top)) gend(I(top)) gend(I(top)) gstrt(I(top))]'+chrom_l(CHR(1)),...
        repmat(.1,4,length(I(top))),...
        [0 1 0],'facealpha',0.7,'edgecolor','none');
end
if ~isempty(bot)
    p2 = patch(repmat([xl(1) xl(1) xl(2) xl(2)]',1,length(I(bot))),...
        [gstrt(I(bot)) gend(I(bot)) gend(I(bot)) gstrt(I(bot))]'+chrom_l(CHR(1)),...
        [0 0.4 0],'facealpha',0.6,'edgecolor','none');
end
ztext = 10*ones(length(I),1);
ztext(2:2:end) = ztext(2:2:end)+5;
line([repmat(xl(2),length(I),1) repmat(xl(2),length(I),1)]',...
    [(gstrt(I)+gend(I))/2+chrom_l(CHR(1)) (gstrt(I)+gend(I))/2+chrom_l(CHR(1))]',...
    [repmat(0,length(I),1) repmat(10,length(I),1)]','color','k')

t2 = text(repmat(xl(2),length(I),1),(gstrt(I)+gend(I))/2+chrom_l(CHR(1)),ztext,gname(I),...
    'rotation',0,'interpreter','none','backgroundcolor',[1 1 0.6]);
gname(I)

zt = get(gca,'ztick');
zt(1) = 1;
xt = get(gca,'xtick');
[xc,dummy] = abs2chrom(xt,chrom_l,1);
[dummy,xt] = abs2chrom(xt,chrom_l,0);
xt = cellstr(num2str(xt'));
yt = get(gca,'ytick');
[yc,dummy] = abs2chrom(yt,chrom_l,1);
[dummy,yt] = abs2chrom(yt,chrom_l,0);
yt = cellstr(num2str(yt'));
set(gca,'zticklabel',round(label_H(zt)),'ztickmode','manual');
set(gca,'yticklabel',[],'xticklabel',[]) %Remove tick labels
h = get(gca,'ytick'); %Get tick mark positions
ax = axis; %Get left most y-position
for xx = 1:length(h)
%Create text box and set appropriate properties
   tmp_h = text(ax(1),h(xx),yt(xx),'HorizontalAlignment','Right');   
   set(tmp_h,'units','centimeters');
   tmp_e = get(tmp_h,'position');
   tmp_e(1:2) = [tmp_e(1)-0.3 tmp_e(2)-0.3];
   set(tmp_h,'position',tmp_e);
   set(tmp_h,'units','data');
end
h = get(gca,'xtick'); %Get tick mark positions
ax = axis; %Get left most x-position
for xx = 1:length(h)
%Create text box and set appropriate properties
   tmp_h = text(h(xx),ax(3),xt(xx),'HorizontalAlignment','Left');   
   set(tmp_h,'units','centimeters');
   tmp_e = get(tmp_h,'position');
   tmp_e(1:2) = [tmp_e(1)-0.3 tmp_e(2)-0.3];
   set(tmp_h,'position',tmp_e);
    set(tmp_h,'units','data');
end

MX = [];
MY = [];
for i = 1:sum(~cellfun(@isempty,X))
MX = [MX; X{i}];
MY = [MY; Y{i}];
end
MXY = [mean(mean(MX)) mean(mean(MY))];

tmp_x = target_genes(MXY(1),gstrt+chrom_l(gchr),3,300000);
tmp_x = tmp_x(tmp_x~=0);
G_x = gname(tmp_x);
tmp_y = target_genes(MXY(2),gstrt+chrom_l(gchr),3,300000);
tmp_y = tmp_y(tmp_y~=0);
G_y = gname(tmp_y);
Gx = []; Gy = [];
for i = 1:length(G_x)
    Gx = [Gx G_x{i} ' | '];
end
Gx = Gx(1:end-3);
for i = 1:length(G_y)
    Gy = [Gy G_y{i} ' | '];
end
Gy = Gy(1:end-3);

xlabel(['Chromosome ' xc(1,:) 10 'Putative target: ' Gx],...
    'interpreter','none')
ylabel(['Chromosome ' yc(1,:) 10 'Putative target: ' Gy],...
    'interpreter','none')