%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load Data/chrom_l_36
filename = 'Data/RTCGD_mm8_RV010307.txt';

[CLONE, TUMOR, MODEL, TYPE, AUTHOR, RIS_NAME, MOUSE_SYMB, CIS, REL_LOC, DIST,...
    DIR, CHROM, LOC, HUMAN] = ...
textread(filename,'%s%s%s%s%s%s%s%s%s%s%s%s%n%s','delimiter','\t','headerlines',1);

I                       = find(~cellfun('isempty',(strfind(CHROM,'random'))));
CLONE(I)                = [];
TUMOR(I)                = [];
MODEL(I)                = [];
TYPE(I)                 = [];
AUTHOR(I)               = [];
RIS_NAME(I)             = [];
MOUSE_SYMB(I)           = [];
CIS(I)                  = [];
REL_LOC(I)              = [];
DIST(I)                 = [];
DIR(I)                  = [];
CHROM(I)                = [];
LOC(I)                  = [];
HUMAN(I)                = [];

CHROM                   = char(CHROM);
chr                     = CHROM(:,[4 5]);
I                       = find(chr(:,1)=='X');
chr(I,:)                = repmat('20',size(I));
I                       = find(chr(:,1)=='Y');
chr(I,:)                = repmat('21',size(I));
chr                     = str2num(chr);

chrom_l = cumsum([0; chrom_l_36])';
insertions = LOC+chrom_l(chr)'; %Absolute coordinates
%Do a contig_building
[insertions index contig_depth] = ...
    contig_build_simple(insertions,TUMOR,'Single',1000);

tumor = TUMOR(index);

%Convert tumors to tumorIDs and store the labels
%
[tumlabs, dummy, tumorid] = unique(tumor);
%Determine the number of insertions per tumor
utumid = 1:max(tumorid);
tumcnt = histc(tumorid,utumid);

%Pitch all tumors without co-occurring insertions
I = find(tumcnt>1);
c_tumcnt = tumcnt(I);
c_utumid = utumid(I);
%Make a matrix: rows are tumors, nonzero colums are insertions
insertion_matrix = zeros(length(c_tumcnt),max(c_tumcnt));
for i = 1:length(c_utumid)
   I = find(c_utumid(i)==tumorid);
   if length(I)==1
       disp(i)
   end
   insertion_matrix(i,1:length(I)) = insertions(I)';
end   

%For speed issues we define an array with maximum size
N_all = cumsum(1:max(c_tumcnt));
N = N_all(end);

cooc = zeros(round(length(c_tumcnt)*N/10),2);
t_member = zeros(round(length(c_tumcnt)*N/10),1);
% ind = 1:N:length(c_tumcnt)*N;
allcomb = sortrows(jchoosek((1:max(c_tumcnt))'),2);
ind = 0;
for i = 1:length(c_tumcnt)
    tmp = insertion_matrix(i,:);
    N_tmp = sum(tmp~=0);
    I = allcomb(1:N_all(N_tmp-1),:);
    tmp = tmp(1:N_tmp);
    tmp = tmp(I);
    ind_tmp = ind+N_all(N_tmp-1);
    cooc(ind+1:ind_tmp,1:2) = tmp;
    t_member(ind+1:ind_tmp) = repmat(i,size(tmp,1),1);
    ind = ind_tmp;
    
end
C = cooc(cooc(:,1)~=0 & cooc(:,2)~=0,:);
TM = t_member(t_member~=0);
Nt = c_tumcnt;
save Data/cooc_mm8 C
    


