%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function null_perm(insertion_matrix,thread)
%Thread specifies which part of the simulation to start
%Script to compute the null-distribution for the cooccurrence space

P = 10000; %Number of permutations
G = 2.56e9; %Genome length

H = logspace(log(10000)/log(10),log(500000)/log(10),8);
binsize = round(1500000./H);

%Set the peak finding properties
options = optimset('tolfun',1e-20,'tolx',1,'largescale','on',...
    'gradobj','on','Display','off');

%Determine properties of real data
Nt = sum(insertion_matrix~=0,2);
index = tum_index(Nt);
[T,max_Nt] = size(insertion_matrix);

%Define the lookuptable
lookuptable = sortrows(jchoosek((1:max_Nt)'),2);

cpt = cputime;
peak_heights = zeros(length(H),1000,500); %Make space for 1000 non unity peaks
no_unity_peaks = zeros(length(H),500);
cnt = 1;
file_cnt = 1;
for perm = 1:P
    in = insertion_perm(index,T,max_Nt,G);
    in = findc_lookup(in,lookuptable,T,max_Nt,Nt);
    for i = 1:length(H)
        [peaks,ph,nup]              = parzen2Dpeak(in,H(i),options,binsize(i));
        Lph                         = size(ph,1);
        Lnup                        = size(nup,1);
        peak_heights(i,1:Lph,cnt)   = ph;
        no_unity_peaks(i,cnt)       = nup;
    end
    cnt                         = cnt+1;
    if mod(perm,500)==0
        save(['permres_' num2str(thread) '_' num2str(file_cnt)],'peak_heights','no_unity_peaks');
        disp('File saved! Remaining time in hours: ');
        disp((P-perm)*(cputime-cpt)/1800000);
        cpt                 = cputime;
        file_cnt            = file_cnt + 1;
        cnt                 = 1;
        peak_heights = zeros(length(H),1000,500); %Make space for 1000 non unity peaks
        no_unity_peaks = zeros(length(H),500);
    end
end

%exit

