%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%CHI-SQUARE POST PROCESSING
load Data/P_total
load Data/genes
load Data/csCCI_chi
load Data/chrom_l_36
load Data/cooc_mm8

% Complete the co-occurrence space
in = [C; [C(:,2) C(:,1)]];

chi_filter = zeros(1,max(cI));
for i = 1:max(cI)
    chi_filter(i) = sum(Pval_I(cI==i)>0.05)==length(find(cI==i));
end

I_interest = find(~chi_filter);
no_subCI = [];
L = 50;
for i = I_interest %Loop over csCCIs of interest
    P = P_total{i}; %Select one
    X = cell(1,4);
    Y = cell(1,4);
    Z = cell(1,4);
    P_scales = length(P):-1:1; %Find out the scales of this csCCI
    no_subCI(P_scales(1)) = 1;
    flag = 0;
    X{1} = P{P_scales(1),1}(1,round(linspace(1,size(P{P_scales(1),1},2),L))); %Start the csCCI
    Y{1} = P{P_scales(1),1}(2,round(linspace(1,size(P{P_scales(1),1},2),L))); %Start the csCCI
    Z{1} = max(P_scales)*ones(1,size(Y{1},2));
    P_scales = P_scales(2:end); %Top scale is always one
    for j = P_scales %Loop over rest of scales
        no_subCI(j) = sum(cellfun(@length,P(j,:))~=0);
        if no_subCI(j)>no_subCI(j+1); %If we have an extra subCCI we have to...
            %Generate a new stac and copy the previous scale
            for jj = 2:no_subCI(j)
                X{jj} = [X{jj}; X{1}(end,:)]; %Add the previous one to the stack first
                Y{jj} = [Y{jj}; Y{1}(end,:)]; %Add the previous one to the stack first
                Z{jj} = [Z{jj}; Z{1}(end,:)]; %Add the previous one to the stack first
            end
            flag = j;
        elseif no_subCI(j)<no_subCI(j+1)
            flag = -1;
        end
        C_stack = zeros(no_subCI(j),2);
        C_CCI = zeros(no_subCI(j),2);
        if j<flag %Check if we have to split or just add
            for jj = 1:no_subCI(j)  %Loop over subCIs in this scale
                %Get centres of the stacks
                C_stack(jj,:) = [mean(X{jj}(end,:)) mean(Y{jj}(end,:))];
                %Get centres of current CCI
                C_CCI(jj,:) = [mean(P{j,jj}(1,:)) mean(P{j,jj}(2,:))];
            end
        end
        for jj = 1:no_subCI(j)  %Loop over subCIs in this scale
            %Determine to which stack to add
            if j<flag
                D_vec = [C_CCI(jj,1)-C_stack(:,1) C_CCI(jj,2)-C_stack(:,2)];
                [D, I] = min( sqrt(D_vec(:,1).^2+D_vec(:,2).^2) );
            elseif flag==0
                I=jj;
            end
            tmp = reorient([X{I}(end,:); Y{I}(end,:)],...
                [P{j,jj}(1,round(linspace(1,size(P{j,jj},2),L))); ...
                P{j,jj}(2,round(linspace(1,size(P{j,jj},2),L)))]);
            D = sqrt((X{I}(end,:)-tmp(1,:)).^2 + (Y{I}(end,:)-tmp(2,:)).^2);
            DT = 2*min(max(tmp(1,:))-min(tmp(1,:)),max(tmp(2,:))-min(tmp(2,:)));
            X{I} = [X{I}; tmp(1,:)]; %add them to the correct stack
            Y{I} = [Y{I}; tmp(2,:)]; %add them to the correct stack
            Z{I} = [Z{I}; j*ones(1,size(Y{I},2));]; %add them to the correct stack
        end
    end
    plot3d_scale(X,Y,Z,synonyms,in,chrom_l_36);
    pause
end
