%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%CHI-SQUARE POST PROCESSING
clear
load Data/cooc_mm8
load Data/chrom_l_36
load Data/csCCI_chi
figure(1); clf; hold on

chrom_l = [0; cumsum(chrom_l_36)];
%Ranking scheme
norm_PH = -ones(100,max(cI)); %init #scales x #csCCI
for i = 1:max(scale_I)
    I = find(scale_I==i);
    PH_h = PH_I(I);
    PH_h = (PH_h-min(PH_h))/max(PH_h);
    norm_PH(i,cI(I)) = PH_h;
end

score = zeros(1,max(cI));
chi = zeros(1,max(cI));
chi_filter = zeros(1,max(cI));
for i = 1:max(cI)
    score(i) = mean(norm_PH(norm_PH(:,i)>=0,i));
    chi(i) = mean(Pval_I(cI==i));
    chi_filter(i) = sum(Pval_I(cI==i)>0.05)==length(find(cI==i));
end

[sort_score, rank_cI] = sort(score,'descend');
[sort_chi, rank_chi] = sort(chi,'ascend');

%Determine position of the CCI
csCCI = zeros(length(sort_score),2);
for i = 1:length(sort_score) %only top 10
    I = find(cI==i);
    pos = flatC_I(I,:);
    csCCI(i,:) = mean(pos);
end

csCCI_ph = csCCI(rank_cI,:); %Ranked based on ranking scheme
csCCI_chi = csCCI(rank_chi,:); %Ranked based on chi-squar

chi_filter = chi_filter(rank_cI); %Use this for filtering
csCCI = csCCI_ph; %Use this one for plotting

%%
h_IC = plot(C(:,2),C(:,1),'.','color',[.75 1 .75],'markersize',3);

%Transform score to markersize
[num,mem] = histc(sort_score,0:0.1:1);
scatter(csCCI(~chi_filter,2),csCCI(~chi_filter,1),(mem(~chi_filter)+3).^2,'r','filled'); hold on
scatter(csCCI(chi_filter==1,2),csCCI(chi_filter==1,1),(mem(chi_filter==1)+3).^2,'b','filled')
axis tight square ij
M = max(max(C));
set(gca,'xlim',[0 M],'ylim',[0 M]);
line([0 M],[0 M],'color','k');
tickpos = chrom_l(2:end)-(chrom_l(2:end)-chrom_l(1:end-1))/2;
ticklabel = {'1','2','3','4','5','6','7','8','9','10','11','12','13','14',...
    '15','16','17','18','19','X','Y'};
%Set the ticks and %ticklabels
set(gca,'xaxislocation','top','xtick',tickpos,'xticklabel',ticklabel,...
    'ytick',tickpos,'yticklabel',ticklabel,...
    'ticklength',[0 0]);
%Redraw ticks
%X
L = M/50;
line([[chrom_l; chrom_l] [chrom_l; chrom_l]]',...
    [[zeros(length(chrom_l),1); repmat(M,length(chrom_l),1)]...
    [zeros(length(chrom_l),1)+L; repmat(M,length(chrom_l),1)-L]]','color','k')
%Y
line([[zeros(length(chrom_l),1); repmat(M,length(chrom_l),1)]...
    [zeros(length(chrom_l),1)+L; repmat(M,length(chrom_l),1)-L]]',...
    [[chrom_l; chrom_l] [chrom_l; chrom_l]]','color','k')
