%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%CHI-SQUARE POST PROCESSING
perform_kernel_conv = true; %If false, it tries to load previously obtained results
%Compute the Cross Scale Common Cooccurrences of Insertions
H = logspace(log(10000)/log(10),log(500000)/log(10),8);
alpha_level = 0.05;
binsize = 1500000./H;
options = optimset('tolfun',1e-20,'tolx',1,'largescale','on',...
    'gradobj','on','Display','off');

%Load permutation results
load Data/null_mm8
%Load chromosome lengths
load Data/chrom_l_36
chrom_l = [0 cumsum(chrom_l_36)'];
% Load Preprocess the data
load Data/cooc_mm8
% Complete the co-occurrence space
in = [C; [C(:,2) C(:,1)]];

if perform_kernel_conv %Can be used to use the previously save data
    peaks = cell(1,length(H)); ph = cell(1,length(H)); nup = zeros(1,length(H));
    for h = 1:length(H)
        [peaks{h},ph{h},nup(h)] = parzen2Dpeak(C,H(h),options,binsize(h));
    end
    save Data/convolution_results_log_scale peaks ph nup
else
    load Data/convolution_results_log_scale
end

%Interpolate 100 intermediate scales
interp_H = logspace(log(10000)/log(10),log(500000)/log(10),100);
interp_binsize = round(1500000./interp_H);

threshold = zeros(size(H));
for h = 1:length(H)
    I = find(1-yCDF{h}<alpha_level/(length(ph{h})+nup(h)));
    threshold(h) = xCDF{h}(I(1));
end
%Interpolate the threshold
interp_threshold = interp1q(H(:),threshold(:),interp_H(:));

if perform_kernel_conv %Can be used to use the previously save data
    peaks = cell(1,100); ph = cell(1,100); nup = zeros(1,100);
    for hh = 1:length(interp_H)
        [peaks{hh},ph{hh},nup(hh)] = parzen2Dpeak(C,interp_H(hh),options,interp_binsize(hh));
    end
    save Data/convolution_results_100
else
    load Data/convolution_results_100
end

%Pool results for all scales
flatC = [];
scale_layer = [];
PH = [];
Pval = [];
for h = 1:length(interp_H)
    CCIs = peaks{h}(ph{h}>interp_threshold(h),:);
    ph_tmp = ph{h}(ph{h}>interp_threshold(h));
    %Post processing
    C = length(CCIs);
    X = zeros(C,1);
    M = zeros(C,1);
    K = zeros(C,1);
    N = repmat(length(in),C,1);
    for i = 1:C
        IX = find(abs(CCIs(i,1)-in(:,1))<interp_H(h));
        IY = find(abs(CCIs(i,2)-in(:,2))<interp_H(h));
        X(i) = length(intersect(IX,IY));
        M(i) = length(IX);
        K(i) = length(IY);   
    end
    P = hygecdf3(X,N,M,K);
    Pval = [Pval; P];
    PH = [PH; ph_tmp];
    flatC = [flatC; CCIs];
    scale_layer = [scale_layer; h*ones(length(P),1)];
end

%Split per chromosome
Ix = zeros(1,length(flatC));
Iy = zeros(1,length(flatC));
for i = 1:length(flatC)
    Ix(i) = find(chrom_l(1:end-1) <= flatC(i,1) & flatC(i,1) <= chrom_l(2:end));
    Iy(i) = find(chrom_l(1:end-1) <= flatC(i,2) & flatC(i,2) <= chrom_l(2:end));
end

%Do hierarchical clustering per chromosome
dend = {};
cI = [];
scale_I = [];
flatC_I = [];
PH_I = [];
Pval_I = [];
cnt = 0;
for i = unique(Ix)
    for j = unique(Iy)
        dC = pdist(flatC(Ix==i&Iy==j,:)); %Select from square of interest
        if ~isempty(dC)
            flatC_I = [flatC_I; flatC(Ix==i & Iy==j,:)]; %Keep the positions in same order
            PH_I = [PH_I; PH(Ix==i & Iy==j)];
            Pval_I = [Pval_I; Pval(Ix==i & Iy==j)];
            if length(dC)>2 
                dend{i,j} = linkage(dC,'single');
                cI = [cI(:); cluster(dend{i,j},'cutoff',interp_H(end),'criterion','distance')+cnt];
                scale_I = [scale_I(:); scale_layer(Ix==i&Iy==j)];
                cnt = max(cI);
            elseif length(dC)==2
                error('pdist output is wrong!');
            else
                if dC>interp_H(end)
                    cI = [cI(:); [1; 2]+cnt];
                else
                    cI = [cI(:); [1;1]+cnt];
                end
                scale_I = [scale_I(:); scale_layer(Ix==i&Iy==j)];
                cnt = max(cI);
            end
        end
    end
end
 
save Data/csCCI_chi PH_I scale_I cI flatC_I interp_threshold peaks ph nup Pval_I
disp('done');
