%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Author            : Jeroen de Ridder
% Copyright         : J. de Ridder, J.deRidder@tudelft.nl
%                     Delft University of Technology
%                     P.O. Box 5031, 2600 GA Delft,
%          
%                     The Netherlands Cancer Institute
%                     Plesmanlaan 121, 1066 CX, Amsterdam,
%                     The Netherlands
% 
% Reference paper   : de Ridder, J, Kool, J, Uren, A,
%                     Bot, J, Wessels, L, Reinders, M.
%                     Co-occurrence analysis of insertional
%                     mutagenesis data reveals cooperating
%                     oncogenes. Bioinformatics, 2007, 
%                     23(13), i133-i141
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load Data/csCCI  %contains: PH_I scale_I cI flatC_I interp_threshold peaks ph nup
% Load preprocessed data
load Data/cooc_mm8
% Complete the co-occurrence space
in = [C; [C(:,2) C(:,1)]];

interp_H = logspace(log(10000)/log(10),log(500000)/log(10),100);
maxH = length(interp_H);
P_total = cell(1,max(cI));
for i = 1:max(cI) %Loop over all csCCIs
    I = find(cI==i);
    csCCIs = flatC_I(I,:);
    scale = scale_I(I);
    P = [];
    P_layer = [];
    P_within = [];
    for h = 1:maxH %walks over layers
        H = interp_H(h);
        T = interp_threshold(h);
        II = find(scale==h);
        %Filter some occasional double peak detections
        if ~isempty(II)
            if length(II)>2
                D = pdist(csCCIs(II,:));
                L = linkage(D,'single');
                TI = cluster(L,'cutoff',4*H,'criterion','distance');
                CCIs = zeros(max(TI),2);
                for t = 1:max(TI)
                    CCIs(t,:) = [mean(csCCIs(II(TI==t),1)) mean(csCCIs(II(TI==t),2))];
                end
            elseif length(II)==2
                if pdist(csCCIs(II,:))<0.1*H
                    CCIs = [mean(csCCIs(II,1)) mean(csCCIs(II,2))];
                else
                    CCIs = csCCIs(II,:);
                end
            elseif length(II)==1
                CCIs = csCCIs(II,:);
            end
            for j = 1:size(CCIs,1)
                I = find(in(:,1)>CCIs(j,1)-5*H & ...
                    in(:,1)<CCIs(j,1)+5*H &...
                    in(:,2)<CCIs(j,2)+5*H & ...
                    in(:,2)>CCIs(j,2)-5*H); %Trace back the contributing ICs
                ICs = in(I,:);
                %Compute mesh
                GLIM = [min(ICs(:,1))-2*H max(ICs(:,1))+2*H...
                    min(ICs(:,2))-2*H max(ICs(:,2))+2*H];
                STEPS = 150;
                [X,Y] = meshgrid(linspace(GLIM(1),GLIM(2),STEPS),linspace(GLIM(3),GLIM(4),STEPS));

                x = [X(:), Y(:)];
                Z = reshape(local_parzen2D_contour(ICs,x,H,T),size(X));

                CC = contourc(unique(X(:)),unique(Y(:)),Z,[T T]);
                %Select the contour
                C1 = {};
                if ~isempty(CC)
                C1 = split_contour(CC);
                else
                    C1{j} = CCIs(j,:)';
                end
                P_total{i}(h,j:j+length(C1)-1) = C1;
                if length(C1)>1
                    break; %Stop if we have more than one
                end
            end
        end
    end
end
save Data/P_total P_total
